Changelog
=========

.. include:: includes/all.rst

This project adheres to `Semantic Versioning <http://semver.org/spec/v2.0.0.html>`__
and `human-readable changelog <http://keepachangelog.com/en/0.3.0/>`__.


yaml4rst v0.1.0 - unreleased
----------------------------

Added
~~~~~

- Initial coding and design. [ypid_]
